"""src/eones/locales/es.py"""

MESSAGES = {
    "past": "hace",
    "future": "en",
    "year": ("año", "años"),
    "month": ("mes", "meses"),
    "week": ("semana", "semanas"),
    "day": ("día", "días"),
    "hour": ("hora", "horas"),
    "minute": ("minuto", "minutos"),
    "second": ("segundo", "segundos"),
    "just_now": "ahora mismo",
}
