"""src/eones/locales/en.py"""

MESSAGES = {
    "past": "ago",
    "future": "in",
    "year": ("year", "years"),
    "month": ("month", "months"),
    "week": ("week", "weeks"),
    "day": ("day", "days"),
    "hour": ("hour", "hours"),
    "minute": ("minute", "minutes"),
    "second": ("second", "seconds"),
    "just_now": "just now",
}
